Trait Pathway

pub trait Pathway {
    type Capture: 'static;
    type Backend: for<'a> Backend<Self::Key<'a>> + Send + Sync + 'static;
    type Format: Format;
    type Key<'a>;

    // Required methods
    fn key(&self) -> Self::Key<'_>;
    fn capture(&self, world: &World) -> impl FlowLabel;
    fn apply(&self, world: &World) -> impl FlowLabel;
}
Trait that defines how exactly your app saves and loads.

Unlike Pipeline, Pathway allows you to define custom capture types and utilize Flows.

Required Associated Types

type Capture: 'static

The type to be captured from and applied to the world

type Backend: for<'a> Backend<Self::Key<'a>> + Send + Sync + 'static

The interface between the saver / loader and data storage.

type Format: Format

The format used for serializing and deserializing data.

type Key<'a>

Used to uniquely identify each saved capture.

Required Methods

fn key(&self) -> Self::Key<'_>

Retrieve the unique identifier for the capture being processed by the Pathway.

fn capture(&self, world: &World) -> impl FlowLabel

The label of the capture Flow the Pathway will use

fn apply(&self, world: &World) -> impl FlowLabel

The label of the apply Flow the Pathway will use

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.

Implementors

Source

impl<P> Pathway for P
where P: Pipeline + 'static,

Available on crate feature reflect only.