Struct bevy_save::Rollbacks

source ·
pub struct Rollbacks { /* private fields */ }
The global registry of snapshots used for rollback / rollforward.

Implementations

source

impl Rollbacks

source

pub fn is_empty(&self) -> bool

Returns true if no checkpoints have been created.

source

pub fn checkpoint(&mut self, rollback: Rollback)

Given a new Rollback, insert it and set it as the currently active rollback.

If you rollback and then insert a checkpoint, it will erase all rollforward snapshots.

source

pub fn rollback(&mut self, checkpoints: isize) -> Option<&Rollback>

Rolls back the given number of checkpoints.

If checkpoints is negative, it rolls forward.

This function will always clamp itself to valid rollbacks. Rolling back or further farther than what is valid will just return the oldest / newest snapshot.