pub struct Rollbacks { /* private fields */ }Expand description
The global registry of snapshots used for rollback / rollforward.
Implementations
sourceimpl Rollbacks
impl Rollbacks
sourcepub fn checkpoint(&mut self, rollback: Rollback)
pub fn checkpoint(&mut self, rollback: Rollback)
Given a new Rollback, insert it and set it as the currently active rollback.
If you rollback and then insert a checkpoint, it will erase all rollforward snapshots.
sourcepub fn rollback(&mut self, checkpoints: isize) -> Option<&Rollback>
pub fn rollback(&mut self, checkpoints: isize) -> Option<&Rollback>
Rolls back the given number of checkpoints.
If checkpoints is negative, it rolls forward.
This function will always clamp itself to valid rollbacks. Rolling back or further farther than what is valid will just return the oldest / newest snapshot.